[Libreoffice-commits] core.git: include/editeng include/sfx2 include/svl svl/source

Jochen Nitschke j.nitschke+logerrit at ok.de
Thu Sep 29 06:56:39 UTC 2016


 include/editeng/unotext.hxx                |    2 +-
 include/sfx2/DocumentMetadataAccess.hxx    |    4 ++--
 include/sfx2/Metadatable.hxx               |    5 ++---
 include/sfx2/docstoragemodifylistener.hxx  |    4 ++--
 include/sfx2/sfxstatuslistener.hxx         |    4 ++--
 include/sfx2/sidebar/Accessible.hxx        |    4 ++--
 include/sfx2/sidebar/SidebarController.hxx |    4 ++--
 include/sfx2/sidebar/SidebarPanelBase.hxx  |    4 ++--
 include/sfx2/sidebar/Theme.hxx             |    4 ++--
 include/sfx2/sidebar/UnoDeck.hxx           |    5 ++---
 include/sfx2/sidebar/UnoDecks.hxx          |    5 ++---
 include/sfx2/sidebar/UnoPanel.hxx          |    5 ++---
 include/sfx2/sidebar/UnoPanels.hxx         |    5 ++---
 include/sfx2/sidebar/UnoSidebar.hxx        |    5 ++---
 include/sfx2/unoctitm.hxx                  |    6 +++---
 include/svl/itemprop.hxx                   |    6 +++---
 include/svl/style.hxx                      |    6 +++---
 svl/source/items/style.cxx                 |    2 +-
 18 files changed, 37 insertions(+), 43 deletions(-)

New commits:
commit 2bebc1fc2e76f73d953ca1e1f64803fd4c42a62c
Author: Jochen Nitschke <j.nitschke+logerrit at ok.de>
Date:   Wed Sep 28 21:53:59 2016 +0200

    tdf#88206 replace cppu::WeakImplHelper* in sfx2 and svl
    
    some fallout in include/editeng/unotext.hxx
    which uses WeakAggImplHelper1 from implbase1.hxx
    
    Change-Id: I7237c46c1eb17752c63eeddc6a3aee41788fbbd2
    Reviewed-on: https://gerrit.libreoffice.org/29374
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>

diff --git a/include/editeng/unotext.hxx b/include/editeng/unotext.hxx
index 20ee791..6bd0baa 100644
--- a/include/editeng/unotext.hxx
+++ b/include/editeng/unotext.hxx
@@ -44,7 +44,7 @@
 #include <com/sun/star/style/TabStop.hpp>
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <comphelper/interfacecontainer2.hxx>
-#include <cppuhelper/weak.hxx>
+#include <cppuhelper/implbase1.hxx>
 #include <cppuhelper/weakagg.hxx>
 #include <osl/diagnose.hxx>
 #include <osl/mutex.hxx>
diff --git a/include/sfx2/DocumentMetadataAccess.hxx b/include/sfx2/DocumentMetadataAccess.hxx
index 7af6e32..973808d 100644
--- a/include/sfx2/DocumentMetadataAccess.hxx
+++ b/include/sfx2/DocumentMetadataAccess.hxx
@@ -28,7 +28,7 @@
 #include <com/sun/star/rdf/XDocumentMetadataAccess.hpp>
 #include <com/sun/star/rdf/XRepositorySupplier.hpp>
 
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 
 #include <memory>
 
@@ -69,7 +69,7 @@ createBaseURI(
 struct DocumentMetadataAccess_Impl;
 
 class SFX2_DLLPUBLIC DocumentMetadataAccess :
-    public ::cppu::WeakImplHelper1< css::rdf::XDocumentMetadataAccess>
+    public cppu::WeakImplHelper<css::rdf::XDocumentMetadataAccess>
 {
     DocumentMetadataAccess(const DocumentMetadataAccess&) = delete;
     DocumentMetadataAccess& operator=( const DocumentMetadataAccess& ) = delete;
diff --git a/include/sfx2/Metadatable.hxx b/include/sfx2/Metadatable.hxx
index 2d7bc54..b838c9f 100644
--- a/include/sfx2/Metadatable.hxx
+++ b/include/sfx2/Metadatable.hxx
@@ -23,7 +23,7 @@
 
 #include <sfx2/dllapi.h>
 
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <com/sun/star/rdf/XMetadatable.hpp>
 
 #include <memory>
@@ -135,8 +135,7 @@ private:
        Metadatable.</p>
  */
 class SFX2_DLLPUBLIC MetadatableMixin :
-    public ::cppu::WeakImplHelper1<
-        css::rdf::XMetadatable>
+    public cppu::WeakImplHelper<css::rdf::XMetadatable>
 {
 
 public:
diff --git a/include/sfx2/docstoragemodifylistener.hxx b/include/sfx2/docstoragemodifylistener.hxx
index 4733e2a..fa1a291 100644
--- a/include/sfx2/docstoragemodifylistener.hxx
+++ b/include/sfx2/docstoragemodifylistener.hxx
@@ -24,7 +24,7 @@
 
 #include <com/sun/star/util/XModifyListener.hpp>
 
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 
 namespace comphelper { class SolarMutex; }
 
@@ -50,7 +50,7 @@ namespace sfx2
 
     //= DocumentStorageModifyListener
 
-    typedef ::cppu::WeakImplHelper1 < css::util::XModifyListener > DocumentStorageModifyListener_Base;
+    typedef cppu::WeakImplHelper<css::util::XModifyListener> DocumentStorageModifyListener_Base;
 
     class SFX2_DLLPUBLIC DocumentStorageModifyListener : public DocumentStorageModifyListener_Base
     {
diff --git a/include/sfx2/sfxstatuslistener.hxx b/include/sfx2/sfxstatuslistener.hxx
index ab9cb1e..c5a18e9 100644
--- a/include/sfx2/sfxstatuslistener.hxx
+++ b/include/sfx2/sfxstatuslistener.hxx
@@ -30,9 +30,9 @@
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/frame/XStatusListener.hpp>
 
-#include <cppuhelper/implbase2.hxx>
+#include <cppuhelper/implbase.hxx>
 
-class SFX2_DLLPUBLIC SfxStatusListener : public ::cppu::WeakImplHelper2<
+class SFX2_DLLPUBLIC SfxStatusListener : public cppu::WeakImplHelper<
                           css::frame::XStatusListener,
                           css::lang::XComponent>
 {
diff --git a/include/sfx2/sidebar/Accessible.hxx b/include/sfx2/sidebar/Accessible.hxx
index eaa3f52..cb1d729 100644
--- a/include/sfx2/sidebar/Accessible.hxx
+++ b/include/sfx2/sidebar/Accessible.hxx
@@ -22,12 +22,12 @@
 #include <com/sun/star/accessibility/XAccessible.hpp>
 #include <com/sun/star/accessibility/XAccessibleContext.hpp>
 
-#include <cppuhelper/compbase1.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/basemutex.hxx>
 
 namespace
 {
-    typedef ::cppu::WeakComponentImplHelper1 <
+    typedef cppu::WeakComponentImplHelper <
         css::accessibility::XAccessible
         > AccessibleInterfaceBase;
 }
diff --git a/include/sfx2/sidebar/SidebarController.hxx b/include/sfx2/sidebar/SidebarController.hxx
index c32e9c4..6b64fde 100644
--- a/include/sfx2/sidebar/SidebarController.hxx
+++ b/include/sfx2/sidebar/SidebarController.hxx
@@ -38,13 +38,13 @@
 #include <com/sun/star/ui/XSidebar.hpp>
 
 #include <boost/optional.hpp>
-#include <cppuhelper/compbase4.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/basemutex.hxx>
 
 
 namespace
 {
-    typedef ::cppu::WeakComponentImplHelper4 <
+    typedef cppu::WeakComponentImplHelper <
         css::ui::XContextChangeEventListener,
         css::beans::XPropertyChangeListener,
         css::ui::XSidebar,
diff --git a/include/sfx2/sidebar/SidebarPanelBase.hxx b/include/sfx2/sidebar/SidebarPanelBase.hxx
index e0943b4..b41a86c 100644
--- a/include/sfx2/sidebar/SidebarPanelBase.hxx
+++ b/include/sfx2/sidebar/SidebarPanelBase.hxx
@@ -22,7 +22,7 @@
 #include <vcl/EnumContext.hxx>
 #include <sfx2/sidebar/IContextChangeReceiver.hxx>
 
-#include <cppuhelper/compbase5.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/basemutex.hxx>
 
 #include <com/sun/star/frame/XController.hpp>
@@ -42,7 +42,7 @@ namespace sfx2 { namespace sidebar {
 namespace
 {
 
-typedef cppu::WeakComponentImplHelper5<css::ui::XContextChangeEventListener,
+typedef cppu::WeakComponentImplHelper<css::ui::XContextChangeEventListener,
                                        css::ui::XUIElement,
                                        css::ui::XToolPanel,
                                        css::ui::XSidebarPanel,
diff --git a/include/sfx2/sidebar/Theme.hxx b/include/sfx2/sidebar/Theme.hxx
index 84552e5..fc9921e 100644
--- a/include/sfx2/sidebar/Theme.hxx
+++ b/include/sfx2/sidebar/Theme.hxx
@@ -23,7 +23,7 @@
 
 #include <tools/color.hxx>
 #include <vcl/image.hxx>
-#include <cppuhelper/compbase2.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/basemutex.hxx>
 #include <tools/gen.hxx>
 #include <rtl/ref.hxx>
@@ -42,7 +42,7 @@ namespace sfx2 { namespace sidebar {
 
 namespace
 {
-    typedef ::cppu::WeakComponentImplHelper2 <
+    typedef cppu::WeakComponentImplHelper <
         css::beans::XPropertySet,
         css::beans::XPropertySetInfo
         > ThemeInterfaceBase;
diff --git a/include/sfx2/sidebar/UnoDeck.hxx b/include/sfx2/sidebar/UnoDeck.hxx
index 9de2feb..43d57b2 100644
--- a/include/sfx2/sidebar/UnoDeck.hxx
+++ b/include/sfx2/sidebar/UnoDeck.hxx
@@ -16,15 +16,14 @@
 #include <com/sun/star/frame/XFrame.hpp>
 #include <com/sun/star/ui/XPanels.hpp>
 
-#include <cppuhelper/compbase1.hxx>
-#include <cppuhelper/weakref.hxx>
+#include <cppuhelper/compbase.hxx>
 
 #include <sfx2/sidebar/SidebarController.hxx>
 #include <sfx2/sidebar/ResourceManager.hxx>
 
 /** get the decks
 */
-class SfxUnoDeck : public ::cppu::WeakImplHelper1< css::ui::XDeck >
+class SfxUnoDeck : public cppu::WeakImplHelper<css::ui::XDeck>
 {
 
 public:
diff --git a/include/sfx2/sidebar/UnoDecks.hxx b/include/sfx2/sidebar/UnoDecks.hxx
index 8857199..e17b7a3 100644
--- a/include/sfx2/sidebar/UnoDecks.hxx
+++ b/include/sfx2/sidebar/UnoDecks.hxx
@@ -18,15 +18,14 @@
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/frame/XFrame.hpp>
 
-#include <cppuhelper/compbase1.hxx>
-#include <cppuhelper/weakref.hxx>
+#include <cppuhelper/compbase.hxx>
 
 #include <sfx2/sidebar/SidebarController.hxx>
 #include <sfx2/sidebar/ResourceManager.hxx>
 
 /** get the decks
 */
-class SfxUnoDecks : public ::cppu::WeakImplHelper1< css::ui::XDecks >
+class SfxUnoDecks : public cppu::WeakImplHelper<css::ui::XDecks>
 {
 
 public:
diff --git a/include/sfx2/sidebar/UnoPanel.hxx b/include/sfx2/sidebar/UnoPanel.hxx
index 88f47e9..a622675 100644
--- a/include/sfx2/sidebar/UnoPanel.hxx
+++ b/include/sfx2/sidebar/UnoPanel.hxx
@@ -16,8 +16,7 @@
 #include <com/sun/star/awt/XWindow.hpp>
 
 
-#include <cppuhelper/compbase1.hxx>
-#include <cppuhelper/weakref.hxx>
+#include <cppuhelper/compbase.hxx>
 
 #include <sfx2/sidebar/SidebarController.hxx>
 #include <sfx2/sidebar/Panel.hxx>
@@ -27,7 +26,7 @@
 
 /** get the Panel
 */
-class SfxUnoPanel : public ::cppu::WeakImplHelper1< css::ui::XPanel >
+class SfxUnoPanel : public cppu::WeakImplHelper<css::ui::XPanel>
 {
 
 public:
diff --git a/include/sfx2/sidebar/UnoPanels.hxx b/include/sfx2/sidebar/UnoPanels.hxx
index f34aefc..3a5848b 100644
--- a/include/sfx2/sidebar/UnoPanels.hxx
+++ b/include/sfx2/sidebar/UnoPanels.hxx
@@ -17,14 +17,13 @@
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/frame/XFrame.hpp>
 
-#include <cppuhelper/compbase1.hxx>
-#include <cppuhelper/weakref.hxx>
+#include <cppuhelper/compbase.hxx>
 
 #include <sfx2/sidebar/SidebarController.hxx>
 
 /** get the decks
 */
-class SfxUnoPanels : public ::cppu::WeakImplHelper1< css::ui::XPanels >
+class SfxUnoPanels : public cppu::WeakImplHelper<css::ui::XPanels>
 {
 
 public:
diff --git a/include/sfx2/sidebar/UnoSidebar.hxx b/include/sfx2/sidebar/UnoSidebar.hxx
index 79a3386..515ba96 100644
--- a/include/sfx2/sidebar/UnoSidebar.hxx
+++ b/include/sfx2/sidebar/UnoSidebar.hxx
@@ -18,8 +18,7 @@
 
 #include <com/sun/star/awt/XWindow2.hpp>
 
-#include <cppuhelper/compbase1.hxx>
-#include <cppuhelper/weakref.hxx>
+#include <cppuhelper/compbase.hxx>
 
 #include <sfx2/sidebar/SidebarController.hxx>
 #include <sfx2/sidebar/SidebarDockingWindow.hxx>
@@ -29,7 +28,7 @@
 
 /** get the sidebar for a given frame
 */
-class SfxUnoSidebar : public ::cppu::WeakImplHelper1< css::ui::XSidebarProvider >
+class SfxUnoSidebar : public cppu::WeakImplHelper<css::ui::XSidebarProvider>
 {
 
 private:
diff --git a/include/sfx2/unoctitm.hxx b/include/sfx2/unoctitm.hxx
index 9446bc1..aea8220 100644
--- a/include/sfx2/unoctitm.hxx
+++ b/include/sfx2/unoctitm.hxx
@@ -32,7 +32,7 @@
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <com/sun/star/frame/XFrame.hpp>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/interfacecontainer.hxx>
 
 #include <sfx2/ctrlitem.hxx>
@@ -45,7 +45,7 @@ class SfxDispatcher;
 typedef cppu::OMultiTypeInterfaceContainerHelperVar<OUString>
     SfxStatusDispatcher_Impl_ListenerContainer;
 
-class SfxStatusDispatcher   :   public ::cppu::WeakImplHelper1< css::frame::XNotifyingDispatch >
+class SfxStatusDispatcher   :   public cppu::WeakImplHelper<css::frame::XNotifyingDispatch>
 {
     ::osl::Mutex        aMutex;
     SfxStatusDispatcher_Impl_ListenerContainer  aListeners;
@@ -70,7 +70,7 @@ public:
 
 class SfxSlotServer;
 class SfxDispatchController_Impl;
-class SfxOfficeDispatch : public ::cppu::ImplInheritanceHelper1< SfxStatusDispatcher, css::lang::XUnoTunnel >
+class SfxOfficeDispatch : public cppu::ImplInheritanceHelper<SfxStatusDispatcher, css::lang::XUnoTunnel>
 {
 friend class SfxDispatchController_Impl;
     std::unique_ptr<SfxDispatchController_Impl>  pImpl;
diff --git a/include/svl/itemprop.hxx b/include/svl/itemprop.hxx
index 216efdd..026e1b2 100644
--- a/include/svl/itemprop.hxx
+++ b/include/svl/itemprop.hxx
@@ -22,7 +22,7 @@
 #include <com/sun/star/beans/XPropertySetInfo.hpp>
 #include <com/sun/star/beans/PropertyState.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <svl/itemset.hxx>
 #include <svl/svldllapi.h>
 #include <vector>
@@ -155,7 +155,7 @@ public:
 };
 
 struct SfxItemPropertySetInfo_Impl;
-class SVL_DLLPUBLIC SfxItemPropertySetInfo : public cppu::WeakImplHelper1<css::beans::XPropertySetInfo>
+class SVL_DLLPUBLIC SfxItemPropertySetInfo : public cppu::WeakImplHelper<css::beans::XPropertySetInfo>
 {
     std::unique_ptr<SfxItemPropertySetInfo_Impl> m_pImpl;
 
@@ -179,7 +179,7 @@ public:
 
 };
 
-class SVL_DLLPUBLIC SfxExtItemPropertySetInfo: public cppu::WeakImplHelper1<css::beans::XPropertySetInfo >
+class SVL_DLLPUBLIC SfxExtItemPropertySetInfo: public cppu::WeakImplHelper<css::beans::XPropertySetInfo>
 {
     SfxItemPropertyMap aExtMap;
 public:
diff --git a/svl/source/items/style.cxx b/svl/source/items/style.cxx
index f4ab21c..aa9ea3a 100644
--- a/svl/source/items/style.cxx
+++ b/svl/source/items/style.cxx
@@ -929,7 +929,7 @@ SfxStyleSheetBase* SfxStyleSheetPool::Create( const OUString& rName,
 }
 
 SfxUnoStyleSheet::SfxUnoStyleSheet( const OUString& _rName, const SfxStyleSheetBasePool& _rPool, SfxStyleFamily _eFamily, sal_uInt16 _nMaske )
-: ::cppu::ImplInheritanceHelper2< SfxStyleSheet, css::style::XStyle, css::lang::XUnoTunnel >( _rName, _rPool, _eFamily, _nMaske )
+: cppu::ImplInheritanceHelper<SfxStyleSheet, css::style::XStyle, css::lang::XUnoTunnel>(_rName, _rPool, _eFamily, _nMaske)
 {
 }
 


More information about the Libreoffice-commits mailing list
diff --git a/include/svl/style.hxx b/include/svl/style.hxx
index 48e4586..59fd6cf 100644
--- a/include/svl/style.hxx
+++ b/include/svl/style.hxx
@@ -25,7 +25,7 @@
 
 #include <rtl/ref.hxx>
 #include <comphelper/weak.hxx>
-#include <cppuhelper/implbase2.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <svl/svldllapi.h>
 #include <rsc/rscsfx.hxx>
 #include <svl/hint.hxx>
@@ -273,7 +273,7 @@ public:
     virtual bool        SetParent( const OUString& ) override;
 
 protected:
-    SfxStyleSheet() // do not use! needed by MSVC at compile time to satisfy ImplInheritanceHelper2
+    SfxStyleSheet() // do not use! needed by MSVC at compile time to satisfy ImplInheritanceHelper
         : SfxStyleSheetBase(OUString("dummy"), nullptr, SfxStyleFamily::All, 0)
     {
         assert(false);
@@ -332,7 +332,7 @@ public:
     const OUString&     GetOldName() const { return aName; }
 };
 
-class SVL_DLLPUBLIC SfxUnoStyleSheet : public ::cppu::ImplInheritanceHelper2< SfxStyleSheet, css::style::XStyle, css::lang::XUnoTunnel >
+class SVL_DLLPUBLIC SfxUnoStyleSheet : public cppu::ImplInheritanceHelper<SfxStyleSheet, css::style::XStyle, css::lang::XUnoTunnel>
 {
 public:
     SfxUnoStyleSheet( const OUString& _rName, const SfxStyleSheetBasePool& _rPool, SfxStyleFamily _eFamily, sal_uInt16 _nMaske );